Learn R Programming

odetector (version 1.0.1)

pairs.outliers: Scatter plots for diagnosing outliers

Description

Plots the scatter plots showing the outliers found in a data set.

Usage

# S3 method for outliers
pairs(x, ...)

Value

scatter plots showing the outliers by the variable pairs.

Arguments

x

an object of outliers class containing the outliers to be plotted.

...

additional arguments for S3 method pairs.

Author

Zeynel Cebeci, Cagatay Cebeci, Yalcin Tahtali

See Also

detect.outliers, plot.outliers, print.outliers, remove.outliers, summary.outliers

Examples

Run this code
# Load the dataset x3p4c and extract the first three columns to x 
data(x3p4c)
x <- x3p4c[,1:3]

# For 4 clusters, run Unsupervised Possibilistic Fuzzy C-Means (UPFC) algorithm 
# of the package ppclust 
res.upfc <- ppclust::upfc(x, centers=4)

# Detect the outliers 
out <- detect.outliers(res.upfc)
 
# Plot the outliers by the variable pairs
pairs(out)

Run the code above in your browser using DataLab