Learn R Programming

odetector (version 1.0.1)

summary.outliers: Summary of outliers

Description

Summarizes the detected outliers for a data set.

Usage

# S3 method for outliers
summary(object, ...)

Value

Print out of the descriptive statistics for the outliers in an object of outliers class.

Arguments

object

an object of outliers class containing the outliers to be summarized. See detect.outliers for the details.

...

additional arguments for S3 method summary.

Author

Zeynel Cebeci, Yalcin Tahtali, Cagatay Cebeci

See Also

detect.outliers, pairs.outliers, plot.outliers, print.outliers, remove.outliers

Examples

Run this code
# Load the dataset x3p4c and extract the first three columns to x 
data(x3p4c)
x <- x3p4c[,1:3]

# For 4 clusters, run Unsupervised Possibilistic Fuzzy C-Means (UPFC) algorithm
# of the package ppclust 
res.upfc <- ppclust::upfc(x, centers=4)

# Detect the outliers 
out <- detect.outliers(res.upfc)
 
# Summarize the outliers
summary(out)

Run the code above in your browser using DataLab